/**
 * 
 */
package org.test;

import java.util.HashMap;
import java.util.Map;

import javax.jms.Connection;
import javax.jms.Destination;
import javax.jms.JMSException;

import org.hornetq.api.core.TransportConfiguration;
import org.hornetq.api.jms.HornetQJMSClient;
import org.hornetq.api.jms.JMSFactoryType;
import org.hornetq.core.remoting.impl.netty.TransportConstants;
import org.hornetq.jms.client.HornetQConnectionFactory;

public abstract class TestBase
{
    // private static final String DESTINATION_NAME = "Q";
    // private static final JMSFactoryType CF_TYPE = JMSFactoryType.QUEUE_CF;

    private static final String DESTINATION_NAME = "A";

    private static final JMSFactoryType CF_TYPE = JMSFactoryType.TOPIC_CF;

    protected Connection createConnection() throws JMSException
    {
        final HornetQConnectionFactory connectionFactory = HornetQJMSClient
                .createConnectionFactoryWithoutHA(CF_TYPE,
                        createTransportConfiguration());

        connectionFactory.setRetryInterval(1000);
        connectionFactory.setMaxRetryInterval(60000L);
        connectionFactory.setRetryIntervalMultiplier(1.5);
        connectionFactory.setReconnectAttempts(1000);

        // Unbounded client buffer
        // connectionFactory.setConsumerWindowSize(-1);

        // No client buffer - make server side flow control occur more readily
        connectionFactory.setConsumerWindowSize(0);

        Connection connection = connectionFactory.createConnection();

        return connection;
    }

    protected Destination getDestination(Connection connection)
    {
        if (CF_TYPE == JMSFactoryType.TOPIC_CF)
        {
            return HornetQJMSClient.createTopic(DESTINATION_NAME);
        }

        return HornetQJMSClient.createQueue(DESTINATION_NAME);
    }

    private TransportConfiguration createTransportConfiguration()
    {
        final Map<String, Object> params = getParams();

        return new TransportConfiguration(getConnectorFactoryClassName(),
                params);
    }

    private String getConnectorFactoryClassName()
    {
        return "org.hornetq.core.remoting.impl.netty.NettyConnectorFactory";
    }

    protected Map<String, Object> getParams()
    {
        final Map<String, Object> params = new HashMap<String, Object>();

        params.put("use-nio", "true");

        params.put(TransportConstants.HOST_PROP_NAME, "localhost");
        params.put(TransportConstants.PORT_PROP_NAME, "5445");

        return params;
    }
}
